@@ -1,6 +1,6 @@
 from .koi.scanner import Scanner
 from .koi.token_type import TokenType
-from .koi.token import Token
+from .koi.tokens import Token
 from .koi.parser import Parser
 from .koi.ast_printer import AstPrinter
 from .koi.koi import Koi
