@@ -1,6 +1,16 @@
+from .types import TypeVisitor  # type: ignore
 from .koi_instance import KoiInstance
-from .token import Token
-from .std import Clock, Input, ReadFile, WriteFile, StringDataType
+from .tokens import Token
+from .std import (
+    Clock,
+    Input,
+    ReadFile,
+    WriteFile,
+    StringDataType,
+    StringInstance,
+    Println,
+    Print,
+)
 from .environment import Environment
 from .koi_callable import KoiCallable
 from .koi_class import KoiClass
@@ -27,7 +37,6 @@ from .stmt import (
     Expression,
     Function,
     If,
-    Print,
     Return,
     StmtVisitor,
     Stmt,
@@ -41,7 +50,7 @@ from .koi_runtime_error import KoiRuntimeError
 from typing import List, Dict, Any
 
 
-class Interpreter(ExprVisitor, StmtVisitor):
+class Interpreter(ExprVisitor, StmtVisitor, TypeVisitor):
     def __init__(self) -> None:
         self.globals = Environment()
         self.env = self.globals
@@ -52,6 +61,8 @@ class Interpreter(ExprVisitor, StmtVisitor):
         self.globals.define("read_file", ReadFile())
         self.globals.define("write_file", WriteFile())
         self.globals.define("string", StringDataType())
+        self.globals.define("print", Print())
+        self.globals.define("println", Println())
 
     def interpret(self, statements: List[Stmt]):
         try:
@@ -87,6 +98,9 @@ class Interpreter(ExprVisitor, StmtVisitor):
     def visit_literal_expr(self, expr: Literal):
         return expr.value
 
+    def visit_string_type(self, string: str):
+        return StringInstance(string)
+
     def visit_grouping_expr(self, expr: Grouping):
         return self._evaluate(expr.expression)
 
@@ -114,7 +128,7 @@ class Interpreter(ExprVisitor, StmtVisitor):
             case TokenType.PLUS:
                 if isinstance(left, (int, float)) and isinstance(right, (int, float)):
                     return float(left) + float(right)
-                elif isinstance(left, str):
+                elif isinstance(left, str) or isinstance(left, StringInstance):
                     return str(left) + str(right)
                 else:
                     raise KoiRuntimeError(
@@ -151,11 +165,6 @@ class Interpreter(ExprVisitor, StmtVisitor):
         self._stringify(self._evaluate(stmt.expression))
         return None
 
-    def visit_print_stmt(self, stmt: Print):
-        value = self._evaluate(stmt.expression)
-        print(self._stringify(value))
-        return None
-
     def _evaluate(self, expr: Expr):
         return expr.accept(self)
 
