@@ -3,4 +3,5 @@ import os
 from .clock import Clock
 from .fileio import ReadFile, WriteFile
 from .input import Input
-from .strings import StringDataType
+from .strings import StringDataType, StringInstance
+from .print import Print, Println
